# remirepo/fedora spec file for php-sabre-event6
#
# SPDX-FileCopyrightText:  Copyright 2013-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%bcond_without      tests

# Github
%global gh_commit    70525d519b6fbd8e2cbef4e0dbe69c9d4a3e2db7
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     sabre-io
%global gh_project   event
# Packagist
%global pk_vendor    sabre
%global pk_project   %{gh_project}
# Namespace
%global ns_vendor    Sabre
%global ns_project   Event
# For RPM
%global major        6

Name:           php-%{pk_vendor}-%{pk_project}%{major}
Summary:        Lightweight library for event-based programming
Version:        6.0.1
Release:        1%{?dist}

URL:            http://sabre.io/event
License:        BSD-3-Clause
Source0:        %{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
%if %{with tests}
BuildRequires:  php(language) >= 7.4
# From composer.json, "require-dev": {
#        "friendsofphp/php-cs-fixer": "^3.64",
#        "phpstan/phpstan": "^1.12",
#        "phpstan/phpstan-phpunit": "^1.4",
#        "phpstan/phpstan-strict-rules": "^1.6",
#        "phpstan/extension-installer": "^1.4",
#        "phpunit/phpunit" : "^9.6"
BuildRequires:  phpunit9 >= 9.6
%global phpunit %{_bindir}/phpunit9
# Autoloader
BuildRequires:  php-composer(fedora/autoloader)
%endif

# From composer.json, "require": {
#        "php": "^7.4 || ^8.0"
Requires:       php(language) >= 7.4
# From phpcompatinfo report for version 6.0.1
# Only spl
# Autoloader
Requires:       php-composer(fedora/autoloader)

Provides:       php-composer(%{pk_vendor}/%{pk_project}) = %{version}


%description
This library provides the following event-based concepts:

* EventEmitter.
* Promises.
* An event loop.
* Co-routines.

Full documentation can be found on http://sabre.io/event/

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}

cat << 'EOF' | tee lib/autoload.php
<?php
/* Autoloader for %{name} and its dependencies */
require_once '/usr/share/php/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Sabre\\Event\\', __DIR__);

if (!function_exists('Sabre\\Event\\coroutine')) {
    require_once __DIR__ . '/coroutine.php';
    require_once __DIR__ . '/Loop/functions.php';
    require_once __DIR__ . '/Promise/functions.php';
}
EOF


%build
# nothing to build


%install
mkdir -p   %{buildroot}%{_datadir}/php/%{ns_vendor}
cp -pr lib %{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}


%check
: Check version
php -r '
require "%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php";
echo  Sabre\Event\Version::VERSION . "\n";
exit (Sabre\Event\Version::VERSION === "%{version}" ? 0 : 1);
'

%if %{with tests}
: Run upstream test suite against installed library
ret=0
for cmdarg in "php %{phpunit}" php81 php82 php83 php84; do
  if which $cmdarg; then
    set $cmdarg
    $1 ${2:-%{_bindir}/phpunit9} \
      --bootstrap=%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php \
      --configuration tests/phpunit.xml \
      --verbose || ret=1
  fi
done
exit $ret
%else
: Skip upstream test suite
%endif


%files
%license LICENSE
%doc *md
%doc composer.json
%dir %{_datadir}/php/%{ns_vendor}
     %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}


%changelog
* Thu Feb 13 2025 Remi Collet <remi@remirepo.net> - 6.0.1-1
- update to 6.0.1
- raise dependency on PHP 7.4
- rename to php-sabre-event6
- install in /usr/share/php/Sabre/Event6

* Wed Aug 28 2024 Remi Collet <remi@remirepo.net> - 5.1.7-1
- update to 5.1.7 (no change, CS only)

* Fri Jul 26 2024 Remi Collet <remi@remirepo.net> - 5.1.6-1
- update to 5.1.6

* Thu Jul 25 2024 Remi Collet <remi@remirepo.net> - 5.1.5-1
- update to 5.1.5

* Thu Nov  4 2021 Remi Collet <remi@remirepo.net> - 5.1.4-1
- update to 5.1.4

* Thu Nov  4 2021 Remi Collet <remi@remirepo.net> - 5.1.3-1
- update to 5.1.3

* Mon Oct  5 2020 Remi Collet <remi@remirepo.net> - 5.1.2-1
- update to 5.1.2

* Mon Sep 21 2020 Remi Collet <remi@remirepo.net> - 5.1.1-1
- update to 5.1.1
- switch to phpunit9

* Sat Feb  1 2020 Remi Collet <remi@remirepo.net> - 5.1.0-1
- update to 5.1.0
- raise dependency on PHP 7.1
- switch to phpunit8

* Fri Jul  5 2019 Remi Collet <remi@remirepo.net> - 5.0.3-3
- fix autoloader

* Mon Mar  5 2018 Remi Collet <remi@remirepo.net> - 5.0.3-1
- Update to 5.0.3
- sources from git snapshot

* Sat Oct 21 2017 Remi Collet <remi@remirepo.net> - 5.0.2-1
- rename to php-sabre-event5
- update to 5.0.2
- raise dependency on PHP 7.0

* Sat Oct 29 2016 Remi Collet <remi@fedoraproject.org> - 2.0.2-3
- switch from symfony/class-loader to fedora/autoloader

* Mon Jul 20 2015 Remi Collet <remi@fedoraproject.org> - 2.0.2-1
- update to 2.0.2
- add autoloader

* Fri Jun 13 2014 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- update to 1.0.1
- add provides php-composer(sabre/event)
- change url to http://sabre.io/event

* Tue Dec 31 2013 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- Initial packaging
